summaryrefslogtreecommitdiffstats
path: root/lib/kotext/KoTextObject.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /lib/kotext/KoTextObject.h
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/kotext/KoTextObject.h')
-rw-r--r--lib/kotext/KoTextObject.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/kotext/KoTextObject.h b/lib/kotext/KoTextObject.h
index a463d0fc..15574075 100644
--- a/lib/kotext/KoTextObject.h
+++ b/lib/kotext/KoTextObject.h
@@ -192,13 +192,13 @@ public:
* @param defaultHyphenation the default setting for hyphenation (see KoTextFormatCollection)
* @param defaultStyle the style to use by default (initial pararaph, and when deleting a used style)
* @param tabStopWidth the global value for the tabstop width
* @param tqparent tqparent widget for this object
* @param name name for this object
*
*/
KoTextObject( KoTextZoomHandler *zh, const TQFont& defaultFont, const TQString &defaultLanguage,
bool defaultHyphenation, KoParagStyle* defaultStyle, int tabStopWidth = -1,
- TQObject* tqparent = 0, const char *name = 0 );
+ TQObject* parent = 0, const char *name = 0 );
/** Alternative constructor.
* This constructor allows to use a derived class from KoTextDocument.
@@ -206,11 +206,11 @@ public:
* @param textdoc the text document to use in this text object. Ownership is transferred
* to the text object.
* @param defaultStyle the style to use by default (initial pararaph, and when deleting a used style)
* @param tqparent tqparent widget for this object
* @param name name for this object
*/
KoTextObject( KoTextDocument *textdoc, KoParagStyle* defaultStyle,
- TQObject* tqparent = 0, const char *name = 0 );
+ TQObject* parent = 0, const char *name = 0 );
virtual ~KoTextObject();
@@ -562,7 +562,7 @@ public: // made public for KWTextFrameSet...
int eid; // id of last parag
int index; // index (for insertion/deletion)
Type type; // type of command
- KoTextObject* textobj; // tqparent
+ KoTextObject* textobj; // parent
CustomItemsMap customItemsMap; // character position -> qtextcustomitem
TQValueList<KoParagLayout> oldParagLayouts;
KoParagLayout newParagLayout;
@@ -192,13 +192,13 @@ public:
* @param defaultStyle the style to use by default (initial pararaph, and when deleting a used style)
* @param tabStopWidth the global value for the tabstop width
- * @param tqparent tqparent widget for this object
+ * @param parent parent widget for this object
* @param name name for this object
*
@@ -206,11 +206,11 @@ public:
* to the text object.
* @param defaultStyle the style to use by default (initial pararaph, and when deleting a used style)
- * @param tqparent tqparent widget for this object
+ * @param parent parent widget for this object
* @param name name for this object
*/